@@ -4,6 +4,7 @@
 
 
 ##-----------------------------------------------------------------------------
-mod <- function(x, y)
-    x %% y
+mod <- function(x, y) {
+    return(x %% y)
+}
 
